==> apache-streampipes-0.90.0-source-release.zip: apache-streampipes-0.90.0/ui/src/app/data-explorer/components/widgets/base/data-explorer-widget-data.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

import { EventEmitter } from '@angular/core';
import { GridsterItem, GridsterItemComponent } from 'angular-gridster2';
import {
  DashboardItem,
  DataExplorerWidgetModel,
  StreamPipesErrorMessage,
  TimeSettings } from '@streampipes/platform-services';

export interface BaseWidgetData<T extends DataExplorerWidgetModel> {
  removeWidgetCallback: EventEmitter<boolean>;
  timerCallback: EventEmitter<boolean>;
  errorCallback: EventEmitter<StreamPipesErrorMessage>;

  gridsterItem: GridsterItem;
  gridsterItemComponent: GridsterItemComponent;
  editMode: boolean;

  timeSettings: TimeSettings;

  dataViewDashboardItem: DashboardItem;
  dataExplorerWidget: T;
  previewMode: boolean;
  gridMode: boolean;

  cleanupSubscriptions();
}

==> apache-streampipes-0.91.0-source-release.zip: apache-streampipes-0.91.0/ui/src/app/data-explorer/components/widgets/base/data-explorer-widget-data.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

import { EventEmitter } from '@angular/core';
import { GridsterItem, GridsterItemComponent } from 'angular-gridster2';
import {
    DashboardItem,
    DataExplorerWidgetModel,
    StreamPipesErrorMessage,
    TimeSettings,
} from '@streampipes/platform-services';

export interface BaseWidgetData<T extends DataExplorerWidgetModel> {
    removeWidgetCallback: EventEmitter<boolean>;
    timerCallback: EventEmitter<boolean>;
    errorCallback: EventEmitter<StreamPipesErrorMessage>;

    gridsterItem: GridsterItem;
    gridsterItemComponent: GridsterItemComponent;
    editMode: boolean;

    timeSettings: TimeSettings;

    dataViewDashboardItem: DashboardItem;
    dataExplorerWidget: T;
    previewMode: boolean;
    gridMode: boolean;

    cleanupSubscriptions();
}
